# Web interface

```bash
helics server
```

![](https://user-images.githubusercontent.com/1813121/179692721-aed68b6e-229b-4bfe-b260-4e464357c91f.png)

![](https://user-images.githubusercontent.com/1813121/179425630-8136366d-2b09-4251-936f-1158a7b40c5b.png)

![](https://user-images.githubusercontent.com/1813121/179425632-9cc1f914-d5bc-44bf-848c-893733729fb6.png)

![](https://user-images.githubusercontent.com/1813121/179692080-b4dc172e-c73e-4982-8d97-17051dca8c26.png)

Demo of web interface:

[Link to demo](https://user-images.githubusercontent.com/1813121/179425246-9e12db06-a317-493c-88af-098fa460d3ec.mov)

![Demo](https://user-images.githubusercontent.com/1813121/179425246-9e12db06-a317-493c-88af-098fa460d3ec.mov)
